@@ -59,6 +59,8 @@ class DataFrameSummary(object):
 
     def _get_pairplot(self,data):
         self.data=data
+        self.continuous=[]
+        self.categorical=[]
         for i in self.data.columns:
              if (self.data[i].nunique()/self.data.shape[0])*100 > 20 : ##unique nos in a column are more than 20% then it is a continuous variable
                 self.continuous.append(i)
